# Release 3.0.1333.1

## 黑石私有网络(bmvpc) 版本：2018-06-25

### 第 6 次发布

发布时间：2025-06-16 01:09:07

本次发布包含了以下内容：

改善已有的文档。

<font color="#dd0000">**预下线接口**：</font>

* AsyncRegisterIps
* BindIpsToNatGateway
* BindSubnetsToNatGateway
* CreateCustomerGateway
* CreateHostedInterface
* CreateNatGateway
* CreateRoutePolicies
* CreateVpc
* CreateVpcPeerConnection
* DeleteNatGateway
* DeleteRoutePolicy
* DeregisterIps
* DownloadCustomerGatewayConfiguration
* ModifyRoutePolicy
* ModifyRouteTable
* UnbindIpsFromNatGateway
* UnbindSubnetsFromNatGateway
* UpgradeNatGateway



## 云游戏(gs) 版本：2019-11-18

### 第 41 次发布

发布时间：2025-06-16 01:19:43

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateAndroidInstancesAccessToken](https://cloud.tencent.com/document/api/1162/119708)
* [DeleteAndroidInstanceBackupFiles](https://cloud.tencent.com/document/api/1162/119709)
* [RenewAndroidInstancesAccessToken](https://cloud.tencent.com/document/api/1162/119707)

修改接口：

* [ModifyAndroidInstancesProperties](https://cloud.tencent.com/document/api/1162/118980)

	* 新增出参：AndroidInstanceErrors

* [ModifyAndroidInstancesResolution](https://cloud.tencent.com/document/api/1162/118032)

	* 新增出参：AndroidInstanceErrors


修改数据结构：

* [AndroidInstanceImage](https://cloud.tencent.com/document/api/1162/40743#AndroidInstanceImage)

	* 新增成员：AndroidVersion




## iOA 零信任安全管理系统(ioa) 版本：2022-06-01

### 第 15 次发布

发布时间：2025-06-16 01:20:22

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [CreateDeviceTask](https://cloud.tencent.com/document/api/1092/119711)
* [DescribeDeviceInfo](https://cloud.tencent.com/document/api/1092/119710)

新增数据结构：

* [DescribeDeviceInfoRspData](https://cloud.tencent.com/document/api/1092/102488#DescribeDeviceInfoRspData)
* [DeviceNetworkInfo](https://cloud.tencent.com/document/api/1092/102488#DeviceNetworkInfo)
* [DeviceProcessInfo](https://cloud.tencent.com/document/api/1092/102488#DeviceProcessInfo)
* [DeviceServiceInfo](https://cloud.tencent.com/document/api/1092/102488#DeviceServiceInfo)



## 腾讯云智能体开发平台(lke) 版本：2023-11-30

### 第 48 次发布

发布时间：2025-06-16 01:23:17

本次发布包含了以下内容：

改善已有的文档。

修改接口：

* [DescribeApp](https://cloud.tencent.com/document/api/1759/105072)

	* 新增出参：IsCopying

* [ListUsageCallDetail](https://cloud.tencent.com/document/api/1759/113595)

	* 新增入参：BillingTag


修改数据结构：

* [CallDetail](https://cloud.tencent.com/document/api/1759/105104#CallDetail)

	* 新增成员：BillingTag




## 容器服务(tke) 版本：2022-05-01



## 容器服务(tke) 版本：2018-05-25

### 第 198 次发布

发布时间：2025-06-16 01:32:10

本次发布包含了以下内容：

改善已有的文档。

新增接口：

* [DescribeMasterComponent](https://cloud.tencent.com/document/api/457/119713)
* [ModifyMasterComponent](https://cloud.tencent.com/document/api/457/119712)



